summaryrefslogtreecommitdiffstats
path: root/src/scanviewer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/scanviewer.h')
-rw-r--r--src/scanviewer.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/scanviewer.h b/src/scanviewer.h
index 00de43b..7dc1306 100644
--- a/src/scanviewer.h
+++ b/src/scanviewer.h
@@ -9,13 +9,13 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include "k3bjobprogressosd_mod.h"
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -26,7 +26,7 @@ class TQListViewItem;
class TQPushButton;
class TQLabel;
class KProcIO;
-class KConfig;
+class TDEConfig;
class KURLRequester;
class KProgress;
class K3bJobProgressOSD;
@@ -78,14 +78,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
private slots:
@@ -141,7 +141,7 @@ private:
TQLabel *status_label, *status2_label,*matches_label,*matches2_label;
KProcIO *childproc;
TQString buf;
- KConfig* config;
+ TDEConfig* config;
TQStringList lastSearchItems;
TQStringList lastScanPaths;
TQStringList lastQuarItems;
@@ -78,14 +78,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties